@@ -2,7 +2,7 @@ use bevy::math::vec2;
 use bevy::prelude::*;
 use bevy_sprite_grid::prelude::*;
 
-fn spawn_tile_map(
+fn spawn_grid(
     mut commands: Commands,
 ) {
     let cell_size = vec2(32.0, 32.0);
@@ -13,7 +13,7 @@ fn spawn_tile_map(
                 0 => Color::RED,
                 1 => Color::MAROON,
                 _ => Color::WHITE,
-            }
+            }.into()
         );
     commands.spawn_bundle(SpriteGridBundle {
         sprite_grid,
@@ -26,6 +26,6 @@ fn main() {
     .add_plugins(DefaultPlugins)
     .add_plugin(SpriteGridPlugin)
     .add_startup_system(|mut commands: Commands| { commands.spawn_bundle(OrthographicCameraBundle::new_2d()); })
-    .add_startup_system(spawn_tile_map)
+    .add_startup_system(spawn_grid)
     .run();
 }
\ No newline at end of file
