@@ -1,3 +1,4 @@
+use bevy::diagnostic::LogDiagnosticsPlugin;
 use bevy::math::vec2;
 use bevy::prelude::*;
 use bevy_sprite_grid::prelude::*;
@@ -52,6 +53,8 @@ fn main() {
     App::new()
     .add_plugins(DefaultPlugins)
     .add_plugin(SpriteGridPlugin)
+    .add_plugin(LogDiagnosticsPlugin::default())
+    .add_plugin(bevy::diagnostic::FrameTimeDiagnosticsPlugin::default())
     .add_startup_system(|mut commands: Commands| { commands.spawn_bundle(OrthographicCameraBundle::new_2d()); })
     .add_startup_system(spawn_grid)
     .add_system(rotate)
